@@ -16,6 +16,7 @@ namespace Okular {
 
 class DocumentPrivate;
 class ExecutorKJSPrivate;
+class Event;
 
 class ExecutorKJS
 {
@@ -23,7 +24,7 @@ class ExecutorKJS
         ExecutorKJS( DocumentPrivate *doc );
         ~ExecutorKJS();
 
-        void execute( const QString &script );
+        void execute( const QString &script, Event *event );
 
     private:
         friend class ExecutorKJSPrivate;
