@@ -49,7 +49,7 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KIO/Global>
-#ifndef Q_OS_WIN
+#ifdef WITH_KACTIVITIES
 #include <KActivities/ResourceInstance>
 #endif
 
@@ -278,12 +278,12 @@ void Shell::openUrl( const QUrl & url, const QString &serializedOptions )
             m_tabWidget->setTabText( activeTab, url.fileName() );
             applyOptionsToPart( activePart, serializedOptions );
             bool openOk = activePart->openUrl( url );
-            const bool isstdin = url.fileName() == QLatin1String( "-" );
+            const bool isstdin = url.fileName() == QLatin1String( "-" ) || url.scheme() == QLatin1String( "fd" );
             if ( !isstdin )
             {
                 if ( openOk )
                 {
-#ifndef Q_OS_WIN
+#ifdef WITH_KACTIVITIES
                     if ( !m_activityResource )
                         m_activityResource = new KActivities::ResourceInstance( window()->winId(), this );
 
@@ -442,6 +442,7 @@ void Shell::fileOpen()
     dlg->setDirectoryUrl( startDir );
     dlg->setAcceptMode( QFileDialog::AcceptOpen );
     dlg->setOption( QFileDialog::HideNameFilterDetails, true );
+    dlg->setFileMode( QFileDialog::ExistingFiles );   // Allow selection of more than one file
 
     QMimeDatabase mimeDatabase;
     QSet<QString> globPatterns;
