@@ -19,14 +19,18 @@ class QCommandLineParser;
 namespace ShellUtils
 {
 
-QUrl urlFromArg(const QString& _arg, const QString& pageArg = QString() );
+typedef bool (*FileExistFunc)( const QString& fileName );
+
+FileExistFunc qfileExistFunc();
+QUrl urlFromArg(const QString& _arg, FileExistFunc exist_func, const QString& pageArg = QString() );
 QString serializeOptions(const QCommandLineParser &args);
-QString serializeOptions(bool startInPresentation, bool showPrintDialog, bool unique, bool noRaise, const QString &page);
-bool unserializeOptions(const QString &serializedOptions, bool *presentation, bool *print, bool *unique, bool *noraise, QString *page);
+QString serializeOptions(bool startInPresentation, bool showPrintDialog, bool showPrintDialogAndExit, bool unique, bool noRaise, const QString &page);
+bool unserializeOptions(const QString &serializedOptions, bool *presentation, bool *print, bool *print_and_exit, bool *unique, bool *noraise, QString *page);
 bool unique(const QString &serializedOptions);
 bool noRaise(const QString &serializedOptions);
 bool startInPresentation(const QString &serializedOptions);
 bool showPrintDialog(const QString &serializedOptions);
+bool showPrintDialogAndExit(const QString &serializedOptions);
 QString page(const QString &serializedOptions);
 
 }
